@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.010002'; # VERSION
+our $VERSION = '0.010003'; # VERSION
 
 use Moose;
 with 'MooseY::RemoteHelper::Role::Client';
@@ -22,6 +22,8 @@ use XML::Compile::SOAP::WSS 1.04;
 use XML::Compile::WSDL11;
 use XML::Compile::SOAP11;
 use XML::Compile::Transport::SOAPHTTP;
+use File::ShareDir::ProjectDistDir 1.000
+	dist_file => defaults => {  strict => 1 };
 
 our @CARP_NOT = ( __PACKAGE__, qw( Class::MOP::Method::Wrapped ) );
 
@@ -101,7 +103,6 @@ sub _build_cybs_wsdl {
 
 	my $dir = $self->test ? 'test' : 'production';
 
-	load 'File::ShareDir::ProjectDistDir', 'dist_file';
 	return dist_file(
 			'Business-CyberSource',
 			$dir
@@ -117,7 +118,6 @@ sub _build_cybs_xsd {
 
 	my $dir = $self->test ? 'test' : 'production';
 
-	load 'File::ShareDir::ProjectDistDir', 'dist_file';
 	return dist_file(
 			'Business-CyberSource',
 			$dir
@@ -271,7 +271,7 @@ Business::CyberSource::Client - User Agent Responsible for transmitting the Resp
 
 =head1 VERSION
 
-version 0.010002
+version 0.010003
 
 =head1 SYNOPSIS
 
