@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.010002'; # VERSION
+our $VERSION = '0.010003'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::MessagePart';
@@ -182,13 +182,33 @@ has _expiration_year => (
 	default     => sub { $_[0]->expiration->year },
 );
 
-foreach my $attr ( qw(
+my @deprecated = ( qw(
 	credit_card_number
 	card_number
 	cvn cvv cvv2
 	cvc2 cid name
 	full_name
-	card_holder ) ) {
+	card_holder
+));
+
+around BUILDARGS => sub {
+	my $orig = shift;
+	my $self = shift;
+
+	my $args = $self->$orig( @_ );
+
+	foreach my $attr (@deprecated ) {
+		if ( exists $args->{$attr} ) {
+			warnings::warnif('deprecated', # this is due to Moose::Exception conflict
+				"$attr deprecated check the perldoc for the actual attribute"
+			);
+		}
+	}
+
+	return $args;
+};
+
+foreach my $attr ( @deprecated ) {
 	my $deprecated = sub {
 		warnings::warnif('deprecated', # this is due to Moose::Exception conflict
 			"$attr deprecated check the perldoc for the actual attribute"
@@ -213,7 +233,7 @@ Business::CyberSource::RequestPart::Card - Credit Card Helper Class
 
 =head1 VERSION
 
-version 0.010002
+version 0.010003
 
 =head1 EXTENDS
 
